decompress

Function decompress 

pub fn decompress(
    preprocessors: &[Preprocessor],
    components: &[Component],
    compressed: &[u8],
) -> Result<Vec<u8>, Error>
Dempress the compressed data with LC using zero or more preprocessors and one or more components.

The compressed data must have been compressed using the same preprocessors and components.

Errors

Errors with